Method: Aws::SimpleDB::Client#create_domain

Defined in:
lib/aws-sdk-simpledb/client.rb

#create_domain(params = {}) ⇒ Struct

The CreateDomain operation creates a new domain. The domain name should be unique among the domains associated with the Access Key ID provided in the request. The CreateDomain operation may take 10 or more seconds to complete.

The client can create up to 100 domains per account.

If the client requires additional domains, go to [ aws.amazon.com/contact-us/simpledb-limit-request/][1].

[1]: aws.amazon.com/contact-us/simpledb-limit-request/

Examples:

Request syntax with placeholder values


resp = client.create_domain({
  domain_name: "String", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :domain_name (required, String)

    The name of the domain to create. The name can range between 3 and 255 characters and can contain the following characters: a-z, A-Z, 0-9, ‘_’, ‘-’, and ‘.’.

Returns:

  • (Struct)

    Returns an empty response.



619
620
621
622
# File 'lib/aws-sdk-simpledb/client.rb', line 619

def create_domain(params = {}, options = {})
  req = build_request(:create_domain, params)
  req.send_request(options)
end