Method: Aws::SimpleDB::Types::PutAttributesRequest#expected

Defined in:
lib/aws-sdk-simpledb/types.rb

#expectedTypes::UpdateCondition

The update condition which, if specified, determines whether the specified attributes will be updated or not. The update condition must be satisfied in order for this request to be processed and the attributes to be updated.



455
456
457
458
459
460
461
462
# File 'lib/aws-sdk-simpledb/types.rb', line 455

class PutAttributesRequest < Struct.new(
  :domain_name,
  :item_name,
  :attributes,
  :expected)
  SENSITIVE = []
  include Aws::Structure
end