Method: Aws::SimpleDB::Types::DeleteAttributesRequest#attributes
- Defined in:
- lib/aws-sdk-simpledb/types.rb
#attributes ⇒ Array<Types::Attribute>
A list of Attributes. Similar to columns on a spreadsheet, attributes represent categories of data that can be assigned to items.
125 126 127 128 129 130 131 132 |
# File 'lib/aws-sdk-simpledb/types.rb', line 125 class DeleteAttributesRequest < Struct.new( :domain_name, :item_name, :attributes, :expected) SENSITIVE = [] include Aws::Structure end |